@@ -240,20 +240,20 @@ class ArchitectureX86(Architecture):
 
     def _initCategories(self):
         self._categories = {
-                gadget.Category.STACK_PIVOT : (('^sub (?P<dst>.sp), (?P<src>[x0-9a-fA-F]+)$','^add (?P<dst>.sp), (?P<src>[x0-9a-fA-F]+)$','^mov (?P<dst>.sp), .+ ptr \[(?P<src>...)\]$','^mov (?P<dst>.sp), (?P<src>...)$','^xchg (?P<dst>.sp), (?P<src>...)$','^xchg (?P<dst>...), (?P<src>.sp)$','ret.+'),('mov','call','jmp')),
-                gadget.Category.LOAD_MEM : (('mov (?P<dst>...), .+ ptr \[(?P<src>...)\]',),('mov','call','jmp')),
-                gadget.Category.WRITE_MEM : (('^mov .+ ptr \[(?P<dst>...)\], (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.LOAD_REG : (('pop (?P<dst>...)',),('mov','call','jmp')),
+                gadget.Category.STACK_PIVOT : (('^sub (?P<dst>.sp), (?P<src>[x0-9a-fA-F]+)$','^add (?P<dst>.sp), (?P<src>[x0-9a-fA-F]+)$','^mov (?P<dst>.sp), .+ ptr \[(?P<src>...)\]$','^mov (?P<dst>.sp), (?P<src>...)$','^xchg (?P<dst>.sp), (?P<src>...)$','^xchg (?P<dst>...), (?P<src>.sp)$','ret.+'),('push','mov','call','jmp')),
+                gadget.Category.LOAD_MEM : (('mov (?P<dst>...), .+ ptr \[(?P<src>...)\]',),('push','mov','call','jmp')),
+                gadget.Category.WRITE_MEM : (('^mov .+ ptr \[(?P<dst>...)\], (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.LOAD_REG : (('pop (?P<dst>...)',),('push','mov','call','jmp')),
                 gadget.Category.JMP : (('^jmp (?P<dst>...)$',),()),
-                gadget.Category.CALL : (('^call (?P<dst>...)$',),('mov','call','jmp')),
-                gadget.Category.INC_REG : (('^inc (?P<dst>...)$', '^add (?P<dst>e?..), 1$'),('mov','call','jmp')),
-                gadget.Category.CLEAR_REG : (('^xor (?P<dst>...), (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.SUB_REG : (('^sub (?P<dst>...), (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.ADD_REG : (('^add (?P<dst>...), (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.XCHG_REG : (('^xchg (?P<dst>...), (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.PUSHAD : (('^pushal$',),('mov','call','jmp')),
-                gadget.Category.NEG_REG : (('^neg (?P<dst>...)$',),('mov','call','jmp')),
-                gadget.Category.SYSCALL : (('^int (?P<dst>0x80)$',),('mov','call','jmp'))}
+                gadget.Category.CALL : (('^call (?P<dst>...)$',),('push','mov','call','jmp')),
+                gadget.Category.INC_REG : (('^inc (?P<dst>...)$', '^add (?P<dst>e?..), 1$'),('push','mov','call','jmp')),
+                gadget.Category.CLEAR_REG : (('^xor (?P<dst>...), (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.SUB_REG : (('^sub (?P<dst>...), (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.ADD_REG : (('^add (?P<dst>...), (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.XCHG_REG : (('^xchg (?P<dst>...), (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.PUSHAD : (('^pushal$',),('push','mov','call','jmp')),
+                gadget.Category.NEG_REG : (('^neg (?P<dst>...)$',),('push','mov','call','jmp')),
+                gadget.Category.SYSCALL : (('^int (?P<dst>0x80)$',),('push','mov','call','jmp'))}
 
 
 
@@ -290,20 +290,20 @@ class ArchitectureX86_64(ArchitectureX86):
 
     def _initCategories(self):
         self._categories = {
-                gadget.Category.STACK_PIVOT : (('^mov (?P<dst>.sp), .+ ptr \[(?P<src>...)\]$','^mov (?P<dst>.sp), (?P<src>...)$','^xchg (?P<dst>.sp), (?P<src>...)$','^xchg (?P<dst>...), (?P<src>.sp)$','ret.+'),('mov','call','jmp')),
-                gadget.Category.LOAD_MEM : (('mov (?P<dst>r..), .+ ptr \[(?P<src>r..)\]',),('mov','call','jmp')),
-                gadget.Category.WRITE_MEM : (('^mov .+ ptr \[(?P<dst>r..)\], (?P<src>r..)$',),('mov','call','jmp')),
-                gadget.Category.LOAD_REG : (('pop (?P<dst>r..)',),('mov','call','jmp')),
+                gadget.Category.STACK_PIVOT : (('^mov (?P<dst>.sp), .+ ptr \[(?P<src>...)\]$','^mov (?P<dst>.sp), (?P<src>...)$','^xchg (?P<dst>.sp), (?P<src>...)$','^xchg (?P<dst>...), (?P<src>.sp)$','ret.+'),('push','mov','call','jmp')),
+                gadget.Category.LOAD_MEM : (('mov (?P<dst>r..), .+ ptr \[(?P<src>r..)\]',),('push','mov','call','jmp')),
+                gadget.Category.WRITE_MEM : (('^mov .+ ptr \[(?P<dst>r..)\], (?P<src>r..)$',),('push','mov','call','jmp')),
+                gadget.Category.LOAD_REG : (('pop (?P<dst>r..)',),('push','mov','call','jmp')),
                 gadget.Category.JMP : (('^jmp (?P<dst>r..)$',),()),
-                gadget.Category.CALL : (('^call (?P<dst>r..)$',),('mov','call','jmp')),
-                gadget.Category.INC_REG : (('^inc (?P<dst>...)$', '^add (?P<dst>[er]?..), 1$'),('mov','call','jmp')),
-                gadget.Category.CLEAR_REG : (('^xor (?P<dst>...), (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.SUB_REG : (('^sub (?P<dst>...), (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.ADD_REG : (('^add (?P<dst>...), (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.XCHG_REG : (('^xchg (?P<dst>...), (?P<src>...)$',),('mov','call','jmp')),
-                gadget.Category.PUSHAD : (('^pushal$',),('mov','call','jmp')),
-                gadget.Category.NEG_REG : (('^neg (?P<dst>...)$',),('mov','call','jmp')),
-                gadget.Category.SYSCALL : (('^syscall$',),('mov','call','jmp'))}
+                gadget.Category.CALL : (('^call (?P<dst>r..)$',),('push','mov','call','jmp')),
+                gadget.Category.INC_REG : (('^inc (?P<dst>...)$', '^add (?P<dst>[er]?..), 1$'),('push','mov','call','jmp')),
+                gadget.Category.CLEAR_REG : (('^xor (?P<dst>...), (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.SUB_REG : (('^sub (?P<dst>...), (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.ADD_REG : (('^add (?P<dst>...), (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.XCHG_REG : (('^xchg (?P<dst>...), (?P<src>...)$',),('push','mov','call','jmp')),
+                gadget.Category.PUSHAD : (('^pushal$',),('push','mov','call','jmp')),
+                gadget.Category.NEG_REG : (('^neg (?P<dst>...)$',),('push','mov','call','jmp')),
+                gadget.Category.SYSCALL : (('^syscall$',),('push','mov','call','jmp'))}
 
 
 
